@@ -18,7 +18,7 @@
 
 """"
 Common parameters for CFN
-This is a crucial part as all the titles, maked `_T` are string which are then used the same way
+This is a crucial part as all the titles, marked `_T` are string which are then used the same way
 across all imports, which gives consistency for CFN to use the same names,
 which it heavily relies onto.
 
@@ -43,9 +43,9 @@ VPC_MAP_ID = Parameter(VPC_MAP_ID_T, Type="String", Default="none")
 VPC_MAP_ARN_T = "AwsVpcCloudMapArn"
 VPC_MAP_ARN = Parameter(VPC_MAP_ARN_T, Type="String", Default="none")
 
-SERVICE_DISCOVERY_T = "UseAwsCloudMap"
-SERVICE_DISCOVERY = Parameter(
-    SERVICE_DISCOVERY_T, Type="String", AllowedValues=["True", "False"], Default="True"
+USE_CLOUDMAP_T = "UseAwsCloudMap"
+USE_CLOUDMAP = Parameter(
+    USE_CLOUDMAP_T, Type="String", AllowedValues=["True", "False"], Default="True"
 )
 
 USE_CFN_PARAMS_T = "UseCfnParametersValue"
