@@ -21,7 +21,7 @@ Most commonly used functions shared across all modules.
 """
 
 import json
-from ecs_composex.common import KEYISSET, LOG
+from ecs_composex.common import keyisset, LOG
 
 
 def build_config_template_file(config, parameters=None, tags=None, stack_policies=None):
@@ -37,6 +37,8 @@ def build_config_template_file(config, parameters=None, tags=None, stack_policie
     """
     if parameters is not None and not isinstance(parameters, list):
         raise TypeError("parameters must be a list of objects", list)
+    if not keyisset("Parameters", config):
+        config["Parameters"] = {}
     for param in parameters:
         config["Parameters"].update({param["ParameterKey"]: param["ParameterValue"]})
     return config
@@ -45,9 +47,11 @@ def build_config_template_file(config, parameters=None, tags=None, stack_policie
 def import_parameters_into_config_file(parameters_file, config_file):
     """
     Imports parameter file and outputs it into a CFN Template config file
+
     :param parameters_file: path to the parameters file
+    :type parameters_file: str
     :param config_file: path to the config file.
-    :return:
+    :type config_file: str
     """
     with open(parameters_file, "r") as params_fd:
         parameters = json.loads(params_fd.read())
@@ -57,7 +61,7 @@ def import_parameters_into_config_file(parameters_file, config_file):
                 config = json.loads(config_fd.read())
             except json.decoder.JSONDecodeError:
                 config = {"Parameters": {}}
-            if not KEYISSET("Parameters", config):
+            if not keyisset("Parameters", config):
                 config["Parameters"] = {}
     except FileNotFoundError:
         config = {"Parameters": {}}
