@@ -17,9 +17,12 @@ from botocore.exceptions import ClientError
 from datetime import datetime as dt
 from troposphere import Template
 from ecs_composex.common.ecs_composex import DIR_DEST
-from ecs_composex.common import DATE_PREFIX, KEYISSET
+from ecs_composex.common import DATE_PREFIX, keyisset
 from ecs_composex.common import LOG
 
+JSON_MIME = "application/json"
+YAML_MIME = "application/x-yaml"
+
 
 def check_bucket(bucket_name, session=None, client=None):
     """
@@ -137,7 +140,7 @@ def upload_template(
         session = boto3.session.Session()
     assert check_bucket(bucket_name=bucket_name, session=session)
     if mime is None:
-        mime = "application/json"
+        mime = JSON_MIME
     if prefix is None:
         prefix = DATE_PREFIX
 
@@ -170,7 +173,21 @@ def upload_template(
 
 class FileArtifact(object):
     """
-    Class for a template file built.
+    Class to handle files artifacts, such as configuration files or templates.
+    It will allow to upload the content to S3 or write to local filesystem.
+    It also handles CloudFormation templates validation.
+
+    :cvar str url: The URL in S3 where the file will be uploaded to or available from.
+    :cvar str body: The content of the FileArtifact
+    :cvar troposphere.Template template: the CFN template
+    :cvar str file_name: the base name of the file
+    :cvar str mime: MIME-type of the file
+    :cvar boto3.session.Session session: session for clients to make API calls to AWS
+    :cvar bool can_upload: Indicate whether or not config allows for upload to S3.
+    :cvar bool no_upload: Turns off upload if True
+    :cvar bool validate: Indicates whether the template is validated.
+    :cvar str output_dir: Path to the local director to output the file to.
+    :cvar str file_path: Output file path for the FileArtifact
     """
 
     url = None
@@ -181,13 +198,19 @@ class FileArtifact(object):
     session = boto3.session.Session()
     bucket = None
     can_upload = False
+    no_upload = False
     validated = False
     output_dir = f"/tmp/{dt.utcnow().strftime('%s')}"
     file_path = None
 
     def upload(self):
-        if not self.can_upload:
+        """
+        Method to handle uploading the files to S3.
+        """
+        if not self.can_upload and not self.no_upload:
             LOG.error("BucketName was not specified, not attempting upload")
+        elif self.no_upload:
+            LOG.debug("No Upload is true. Not uploading")
         else:
             self.url = upload_template(
                 self.body, self.bucket, self.file_name, mime=self.mime, validate=False
@@ -195,6 +218,9 @@ class FileArtifact(object):
             LOG.info(f"{self.file_name} uploaded successfully to {self.url}")
 
     def write(self):
+        """
+        Method to write the files to local filesystem based on parameters (directory name etc.)
+        """
         try:
             mkdir(self.output_dir)
             LOG.debug(f"Created directory {self.output_dir} to store files")
@@ -204,58 +230,75 @@ class FileArtifact(object):
             if self.body is None:
                 self.define_body()
             template_fd.write(self.body)
-            LOG.debug(
-                f"Template {self.file_name} written successfully at {self.output_dir}/{self.file_name}"
-            )
+            if self.no_upload:
+                LOG.info(
+                    f"Template {self.file_name} written successfully at {self.output_dir}/{self.file_name}"
+                )
 
     def validate(self):
+        """
+        Method to validate the CloudFormation template, either via URL once uploaded to S3 or via TemplateBody
+        """
         try:
-            if self.url is None:
-                self.upload()
-            self.session.client("cloudformation").validate_template(
-                TemplateURL=self.url
-            )
+            if not self.no_upload:
+                if self.url is None:
+                    self.upload()
+                self.session.client("cloudformation").validate_template(
+                    TemplateURL=self.url
+                )
+            elif self.no_upload:
+                if not self.file_path:
+                    self.write()
+                LOG.debug(f"No upload - Validating template body - {self.file_path}")
+                self.session.client("cloudformation").validate_template(
+                    TemplateBody=self.body
+                )
             LOG.debug(f"Template {self.file_name} was validated successfully by CFN")
             self.validated = True
         except ClientError as error:
             LOG.error(error)
 
     def define_body(self):
+        """
+        Method to define the body of the file artifact. Sets the mime type that will be used for upload into S3.
+        """
         if isinstance(self.template, Template):
-            if self.mime == "application/x-yaml":
+            if self.mime == YAML_MIME:
                 self.body = self.template.to_yaml()
             else:
                 self.body = self.template.to_json()
         elif isinstance(self.content, (list, dict, tuple)):
             self.can_upload = True
-            if self.mime == "application/x-yaml":
+            if self.mime == YAML_MIME:
                 self.body = yaml.dump(self.content, Dumper=Dumper)
-            elif self.mime == "application/json":
+            elif self.mime == JSON_MIME:
                 self.body = json.dumps(self.content, indent=4)
 
     def define_file_specs(self):
         """
-        Function to set the file body from template if self.template is Template
+        Method to set the file body from template if self.template is Template
         """
         if self.file_name.endswith(".json"):
-            self.mime = "application/json"
+            self.mime = JSON_MIME
         elif self.file_name.endswith(".yml") or self.file_name.endswith(".yaml"):
-            self.mime = "application/x-yaml"
+            self.mime = YAML_MIME
 
     def set_from_kwargs(self, **kwargs):
         """
-        Function to set internal settings based on kwargs keys
-        :param kwargs:
+        Method to set internal settings based on kwargs keys
+
+        :param kwargs: unordered parameters
+        :type kwargs: dict
         """
-        if KEYISSET(DIR_DEST, kwargs):
+        if keyisset(DIR_DEST, kwargs):
             self.output_dir = path.abspath(kwargs[DIR_DEST])
-        if KEYISSET("BucketName", kwargs):
+        if keyisset("BucketName", kwargs):
             self.bucket = kwargs["BucketName"]
             self.can_upload = True
 
     def create(self):
         """
-        Function to write to file and upload in a single function
+        Method to sequentially write to file and upload
         """
         self.define_body()
         self.write()
@@ -263,12 +306,15 @@ class FileArtifact(object):
 
     def __init__(self, file_name, template=None, content=None, session=None, **kwargs):
         """
-        Init function for our template file object
+        Init method for FileArtifact
+
         :param file_name: Name of the file. Mandatory
         :param template: If you are providing a template to generate
         :param body: raw content to write
-        :param session:
-        :param kwargs:
+        :param session: boto3 session to use for API calls to AWS.
+        :type session: boto3.session.Session()
+        :param kwargs: unordered arguments
+        :type kwargs: dict
         """
         self.file_name = file_name
         if template is not None and not isinstance(template, Template):
@@ -282,6 +328,8 @@ class FileArtifact(object):
             self.content = content
         self.define_file_specs()
         self.file_path = f"{self.output_dir}/{self.file_name}"
+        if keyisset("NoUpload", kwargs):
+            self.no_upload = True
 
     def __repr__(self):
         return self.file_path
