@@ -85,7 +85,8 @@ def formatted_outputs(comments, obj_name=None, export=True, delimiter=None):
 
 def define_import(resource_name, attribute_name, delimiter=None):
     """
-    Function to generate ImportValue for defined name
+    Wrapper function to define ImportValue for defined resource name
+
     :param delimiter: delimiter between stack name, resource name and attribute
     :param resource_name: name of the resource exported
     :param attribute_name: attribute exported
@@ -93,9 +94,9 @@ def define_import(resource_name, attribute_name, delimiter=None):
     :type resource_name: str
     :return:
     """
-    delimiter = CFN_EXPORT_DELIMITER
-    if delimiter is not None:
-        delimiter = delimiter
+
+    if delimiter is None:
+        delimiter = CFN_EXPORT_DELIMITER
     return If(
         USE_STACK_NAME_CON_T,
         ImportValue(
