@@ -16,7 +16,6 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 
-
 """
 Functions to add to the Cluster template when people want to use SpotFleet for their ECS Cluster.
 """
@@ -41,7 +40,7 @@ from troposphere.applicationautoscaling import (
 
 from troposphere.cloudwatch import Alarm, MetricDimension as CwMetricDimension
 from troposphere.iam import Role
-from ecs_composex.common import LOG, build_template, KEYISSET
+from ecs_composex.common import LOG, build_template, keyisset
 from ecs_composex.iam import service_role_trust_policy
 from ecs_composex.vpc import vpc_params
 from ecs_composex.compute import compute_params, compute_conditions
@@ -80,7 +79,10 @@ def add_fleet_role(template):
 
 
 def define_overrides(region_azs, lt_id, lt_version, spot_config):
-    """Function to generate Overrides for the SpotFleet
+    """
+    From the list of AZs and the configurations set for spotfleet instances, it will generate an override that
+    SpotFleet will use to diversify the compute resources.
+
     :param region_azs: Availability Zones of the region to create the hosts into
     :type region_azs: list
     :param lt_id: Launch template ID
@@ -297,7 +299,7 @@ def generate_spot_fleet_template(region_azs, **kwargs):
     )
     lt_id = Ref(compute_params.LAUNCH_TEMPLATE_ID)
     lt_version = Ref(compute_params.LAUNCH_TEMPLATE_VersionNumber)
-    if not KEYISSET("spot_config", kwargs):
+    if not keyisset("spot_config", kwargs):
         kwargs["spot_config"] = DEFAULT_SPOT_CONFIG
     define_spot_fleet(template, region_azs, lt_id, lt_version, **kwargs)
     return template
