@@ -16,14 +16,14 @@
 #  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """
-Module to generate a full stack with VPC, Cluster, Compute, Services and all X- AWS resources.
+Main module to generate a full stack with VPC, Cluster, Compute, Services and all X- AWS resources.
 """
 
 import re
 from importlib import import_module
 
 import boto3
-from troposphere import Ref, GetAtt, If
+from troposphere import Ref, GetAtt, If, AWS_STACK_NAME
 from troposphere.ecs import Cluster
 
 from ecs_composex.common import (
@@ -33,19 +33,26 @@ from ecs_composex.common import (
     build_parameters_file,
     build_default_stack_parameters,
 )
-from ecs_composex.common import build_template, KEYISSET, load_composex_file
-from ecs_composex.common import validate_resource_title
+from ecs_composex.common import (
+    build_template,
+    keyisset,
+    load_composex_file,
+    validate_resource_title,
+)
+from ecs_composex.common import cfn_conditions
 from ecs_composex.common.cfn_params import (
     ROOT_STACK_NAME_T,
     USE_FLEET,
     USE_FLEET_T,
     USE_ONDEMAND,
     USE_ONDEMAND_T,
+    USE_CLOUDMAP_T,
+    USE_CLOUDMAP,
 )
 from ecs_composex.common.ecs_composex import XFILE_DEST
 from ecs_composex.common.files import FileArtifact
 from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.common.tagging import generate_tags_parameters, add_object_tags
+from ecs_composex.common.tagging import generate_tags_parameters, add_all_tags
 from ecs_composex.compute import create_compute_stack
 from ecs_composex.compute.compute_params import (
     TARGET_CAPACITY_T,
@@ -53,7 +60,7 @@ from ecs_composex.compute.compute_params import (
     MIN_CAPACITY_T,
 )
 from ecs_composex.ecs import ServicesStack
-from ecs_composex.ecs import ecs_params, create_services_templates
+from ecs_composex.ecs import ecs_params
 from ecs_composex.ecs.ecs_conditions import (
     GENERATED_CLUSTER_NAME_CON_T,
     GENERATED_CLUSTER_NAME_CON,
@@ -81,14 +88,16 @@ SUPPORTED_X_MODULES = ["x-rds", "rds", "x-sqs", "sqs"]
 
 
 def get_composex_globals(compose_content):
-    """Parses configs and looks for globals
+    """
+    Parses configs and looks for composex
+
     :param compose_content: the docker composeX content
     :type compose_content: dict
 
     :return: docker compose globals
     :rtype: dict
     """
-    if KEYISSET("configs", compose_content) and KEYISSET(
+    if keyisset("configs", compose_content) and keyisset(
         "composex", compose_content["configs"]
     ):
         return compose_content["configs"]["composex"]
@@ -128,12 +137,12 @@ def get_mod_function(module_name, function_name):
 def get_mod_class(module_name):
     """
     Function to get the XModule class for a specific ecs_composex module
-    :param module_name:
-    :return:
+
+    :param str module_name: Name of the x-module we are looking for.
+    :return: the_class, maps to the main class for the given x-module
     """
     composex_module_name = f"ecs_composex.{module_name}"
     LOG.debug(composex_module_name)
-    res_module = None
     the_class = None
     try:
         res_module = import_module(composex_module_name)
@@ -151,13 +160,14 @@ def get_mod_class(module_name):
 
 
 def generate_x_resources_policies(resources, resource_type, function, **kwargs):
-    """Function to create the policies for the resources of a given type
+    """
+    Function to create the policies for the resources of a given type
 
     :param resources: resources to go over from docker ComposeX file
     :type resources: dict
     :param resource_type: resource type, ie. sqs
     :type resource_type: str
-    :param function: the function to call to get IAM policies to add to service role
+    :param function: the function to call to get IAM policies to add to ecs_service role
     :type function: function pointer
     :param kwargs: optional arguments
     :type kwargs: dict
@@ -170,13 +180,14 @@ def generate_x_resources_policies(resources, resource_type, function, **kwargs):
         assert validate_resource_title(resource_name, resource_type)
         resource = resources[resource_name]
 
-        if KEYISSET("Services", resource):
+        if keyisset("Services", resource):
             mod_policies[resource_name] = function(resource_name, resource, **kwargs)
     return mod_policies
 
 
 def generate_x_resources_envvars(resources, resource_type, function, **kwargs):
-    """Function to create the env vars for the resources of given type
+    """
+    Function to create the env vars for the resources of given type
 
     :param resources: resources to go over for generating envvars
     :type resources: dict
@@ -195,21 +206,21 @@ def generate_x_resources_envvars(resources, resource_type, function, **kwargs):
         assert validate_resource_title(resource_name, resource_type)
         resource = resources[resource_name]
 
-        if KEYISSET("Services", resource):
+        if keyisset("Services", resource):
             mod_envvars[resource_name] = function(resource_name, resource, **kwargs)
     return mod_envvars
 
 
 def apply_x_configs_to_ecs(content, root_template, services_stack, **kwargs):
     """
-    Function that evaluates only the x- sections of the Compose file
-    and generates calls the init function for each.
+    Function that evaluates only the x- resources of the root template and iterates over the resources.
+    If there is an implemented module in ECS ComposeX for that resource to map to the ECS Services, it will
+    execute the function available in the module to apply defined settings to the services stack.
 
-    :param content: docker ComposeX file content
-    :param kwargs: settings for building X related resources
-
-    :return: resource_configs
-    :rtype: dict
+    :param dict content: The compose file content
+    :param troposphere.Template root_template: The root template for ECS ComposeX
+    :param ecs_composex.ecs.ServicesStack services_stack: root stack for services.
+    :param dict kwargs: settings for building X related resources
     """
     for resource_name in root_template.resources:
         resource = root_template.resources[resource_name]
@@ -237,7 +248,7 @@ def generate_vpc_parameters(template, params, **kwargs):
     :type params: list
     """
     for arg in VPC_ARGS:
-        if KEYISSET(arg, kwargs):
+        if keyisset(arg, kwargs):
             build_parameters_file(params, arg, kwargs[arg])
     params = [
         vpc_params.VPC_ID,
@@ -263,12 +274,11 @@ def add_vpc_to_root(root_template, session, tags_params=None, **kwargs):
     :return: vpc_stack
     :rtype: troposphere.cloudformation.Stack
     """
-    if tags_params is None:
-        tags_params = ()
-    vpc_template = create_vpc_template(session=session, **kwargs)
-    parameters = {ROOT_STACK_NAME_T: Ref("AWS::StackName")}
-    for param in tags_params:
-        parameters.update({param.title: Ref(param.title)})
+    vpc_template = create_vpc_template(session=session, tags=tags_params, **kwargs)
+    parameters = {
+        ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME),
+        USE_CLOUDMAP_T: Ref(USE_CLOUDMAP),
+    }
     vpc_stack = root_template.add_resource(
         ComposeXStack(VPC_STACK_NAME, vpc_template, Parameters=parameters, **kwargs)
     )
@@ -304,7 +314,7 @@ def add_compute(
     create_compute = False
     args = [USE_FLEET_T, USE_ONDEMAND_T, "AddComputeResources"]
     for arg in args:
-        if KEYISSET(arg, kwargs):
+        if keyisset(arg, kwargs):
             create_compute = True
     if not create_compute:
         return
@@ -316,7 +326,7 @@ def add_compute(
     root_template.add_parameter(TARGET_CAPACITY)
     compute_template = create_compute_stack(session, **kwargs)
     parameters = {
-        ROOT_STACK_NAME_T: Ref("AWS::StackName"),
+        ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME),
         TARGET_CAPACITY_T: Ref(TARGET_CAPACITY),
         MIN_CAPACITY_T: Ref(TARGET_CAPACITY),
         USE_FLEET_T: Ref(USE_FLEET),
@@ -354,7 +364,7 @@ def add_compute(
     compute_stack = root_template.add_resource(
         ComposeXStack(
             COMPUTE_STACK_NAME,
-            template=compute_template[0],
+            stack_template=compute_template[0],
             Parameters=parameters,
             DependsOn=dependencies,
             **kwargs,
@@ -370,7 +380,6 @@ def add_x_resources(template, session, tags=None, vpc_stack=None, **kwargs):
     """
     content = load_composex_file(kwargs[XFILE_DEST])
     ignore_x = ["x-tags"]
-    # iam_services = ["x-sqs"]
     tcp_services = ["x-rds"]
     depends_on = []
     if tags is None:
@@ -385,13 +394,13 @@ def add_x_resources(template, session, tags=None, vpc_stack=None, **kwargs):
                 x_template = create_function(session=session, **kwargs)
                 if vpc_stack is not None and key in tcp_services:
                     depends_on.append(VPC_STACK_NAME)
-                parameters = {ROOT_STACK_NAME_T: Ref("AWS::StackName")}
+                parameters = {ROOT_STACK_NAME_T: Ref(AWS_STACK_NAME)}
                 for tag in tags:
                     parameters.update({tag.title: Ref(tag.title)})
                 LOG.debug(xclass)
                 xstack = xclass(
                     res_type.strip(),
-                    template=x_template,
+                    stack_template=x_template,
                     Parameters=parameters,
                     DependsOn=depends_on,
                     **kwargs,
@@ -401,11 +410,10 @@ def add_x_resources(template, session, tags=None, vpc_stack=None, **kwargs):
                 template.add_resource(xstack)
 
 
-def add_services(template, depends, session, vpc_stack=None, **kwargs):
+def add_services(depends, session, vpc_stack=None, **kwargs):
     """
     Function to add the microservices root stack
-    :param template: root template
-    :type template: troposphere.Template
+
     :param depends: list of dependencies for the stack
     :type depends: list
     :param session: ovveride boto session for API calls
@@ -414,17 +422,14 @@ def add_services(template, depends, session, vpc_stack=None, **kwargs):
     :type vpc_stack: troposphere.cloudformation.Template
     :param kwargs: optional parameters
     """
-    services_template = create_services_templates(session=session, **kwargs)
-    stack = ServicesStack(
-        "Services", template=services_template, DependsOn=depends, **kwargs
-    )
-    if KEYISSET("CreateCluster", kwargs):
+    stack = ServicesStack("services", template=None, DependsOn=depends, **kwargs)
+    if keyisset("CreateCluster", kwargs):
         stack.add_cluster_parameter({ecs_params.CLUSTER_NAME_T: Ref(ROOT_CLUSTER_NAME)})
     else:
         stack.add_cluster_parameter({ecs_params.CLUSTER_NAME_T: Ref(CLUSTER_NAME)})
     if vpc_stack:
         stack.add_vpc_stack(vpc_stack)
-    return template.add_resource(stack)
+    return stack
 
 
 def add_ecs_cluster(template, depends_on=None):
@@ -443,7 +448,7 @@ def add_ecs_cluster(template, depends_on=None):
     Cluster(
         ROOT_CLUSTER_NAME,
         template=template,
-        ClusterName=If(CLUSTER_NAME_CON_T, Ref("AWS::StackName"), Ref(CLUSTER_NAME_T)),
+        ClusterName=If(CLUSTER_NAME_CON_T, Ref(AWS_STACK_NAME), Ref(CLUSTER_NAME_T)),
         DependsOn=depends_on,
     )
 
@@ -463,7 +468,13 @@ def init_root_template(stack_params, tags=None):
 
     template = build_template(
         "Root template generated via ECS ComposeX",
-        [USE_FLEET, USE_ONDEMAND, CLUSTER_NAME],
+        [USE_FLEET, USE_ONDEMAND, CLUSTER_NAME, USE_CLOUDMAP],
+    )
+    template.add_condition(
+        cfn_conditions.USE_CLOUDMAP_CON_T, cfn_conditions.USE_CLOUDMAP_CON
+    )
+    template.add_condition(
+        cfn_conditions.NOT_USE_CLOUDMAP_CON_T, cfn_conditions.NOT_USE_CLOUDMAP_CON
     )
     if tags and tags[0] and isinstance(tags[0], list):
         add_parameters(template, tags[0])
@@ -495,20 +506,18 @@ def generate_full_template(content, session=None, **kwargs):
     validate_kwargs(["BucketName"], kwargs)
     vpc_stack = None
     depends_on = []
-    services_stack = add_services(
-        template, depends_on, session=session, vpc_stack=vpc_stack, **kwargs
+    services_stack = template.add_resource(
+        add_services(depends_on, session=session, vpc_stack=vpc_stack, **kwargs)
     )
-    if KEYISSET("CreateVpc", kwargs):
-        vpc_stack = add_vpc_to_root(template, session, tags_params[0], **kwargs)
+    if keyisset("CreateVpc", kwargs):
+        vpc_stack = add_vpc_to_root(template, session, tags_params, **kwargs)
         depends_on.append(vpc_stack)
-        add_object_tags(vpc_stack, tags_params[1])
         services_stack.add_vpc_stack(vpc_stack)
     else:
         generate_vpc_parameters(template, stack_params, **kwargs)
-        LOG.debug(stack_params)
-    if KEYISSET(CLUSTER_NAME_T, kwargs):
+    if keyisset(CLUSTER_NAME_T, kwargs):
         build_parameters_file(stack_params, CLUSTER_NAME_T, kwargs[CLUSTER_NAME_T])
-    if KEYISSET("CreateCluster", kwargs):
+    if keyisset("CreateCluster", kwargs):
         add_ecs_cluster(template, depends_on)
         depends_on.append(ROOT_CLUSTER_NAME)
     add_compute(
@@ -522,6 +531,6 @@ def generate_full_template(content, session=None, **kwargs):
     )
     add_x_resources(template, session=session, vpc_stack=vpc_stack, **kwargs)
     apply_x_configs_to_ecs(content, template, services_stack, **kwargs)
-    for resource in template.resources:
-        add_object_tags(template.resources[resource], tags_params[1])
+    add_all_tags(template, tags_params)
+    LOG.debug(stack_params)
     return template, stack_params
