@@ -17,16 +17,16 @@
 
 """Generates the individual SQS Queues templates."""
 
+import boto3
 from troposphere import Tags, Sub, GetAtt, If, Ref
 from troposphere.sqs import Queue, RedrivePolicy
 from troposphere.ssm import Parameter as SsmParameter
 
 from ecs_composex.common import (
     build_template,
-    add_parameters,
     cfn_params,
-    KEYISSET,
-    KEYPRESENT,
+    keyisset,
+    keypresent,
     LOG,
 )
 from ecs_composex.common import validate_kwargs
@@ -38,7 +38,6 @@ from ecs_composex.common.cfn_conditions import (
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME, ROOT_STACK_NAME_T
 from ecs_composex.common.outputs import formatted_outputs
 from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.common.tagging import add_object_tags, generate_tags_parameters
 from ecs_composex.sqs.sqs_params import RES_KEY, SQS_SSM_PREFIX
 from ecs_composex.sqs.sqs_params import (
     SQS_NAME_T,
@@ -64,7 +63,7 @@ def define_queue_tags(properties, queue_name):
     :rtype: troposphere.Tags
     """
     tag_name_exists = False
-    if KEYISSET("Tags", properties):
+    if keyisset("Tags", properties):
         for key in properties["Tags"]:
             if key == "Name":
                 tag_name_exists = True
@@ -147,7 +146,7 @@ def add_ssm_parameters(src_template, queue_obj):
     )
 
 
-def generate_queue_template(queue_name, properties, redrive_queue=None, tags=None):
+def generate_queue_template(queue_name, properties, redrive_queue=None):
     """
     Function that generates a single queue template
 
@@ -181,8 +180,6 @@ def generate_queue_template(queue_name, properties, redrive_queue=None, tags=Non
     else:
         properties["QueueName"] = Sub(f"${{{ROOT_STACK_NAME_T}}}-${{{SQS_NAME_T}}}")
     queue = Queue(queue_name, template=queue_template, **properties)
-    if tags:
-        add_object_tags(queue, tags)
     add_ssm_parameters(queue_template, queue)
     queue_template.add_output(
         formatted_outputs(
@@ -197,7 +194,7 @@ def generate_queue_template(queue_name, properties, redrive_queue=None, tags=Non
     return queue_template
 
 
-def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
+def add_queue_stack(queue_name, queue, queues, session, **kwargs):
     """
     Function to define the Queue template settings for the Nested Stack
 
@@ -220,11 +217,11 @@ def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
         cfn_params.USE_CFN_EXPORTS_T: Ref(cfn_params.USE_CFN_EXPORTS),
         cfn_params.USE_SSM_EXPORTS_T: Ref(cfn_params.USE_SSM_EXPORTS),
     }
-    if KEYPRESENT("Properties", queue):
+    if keypresent("Properties", queue):
         properties = queue["Properties"]
     else:
         properties = {}
-    if KEYISSET("RedrivePolicy", properties):
+    if keyisset("RedrivePolicy", properties):
         redrive_target = properties["RedrivePolicy"]["deadLetterTargetArn"]
         if redrive_target not in queues:
             raise KeyError(
@@ -237,20 +234,14 @@ def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
                 DLQ_NAME_T: GetAtt(redrive_target, f"Outputs.{SQS_NAME_T}"),
             }
         )
-        queue_tpl = generate_queue_template(
-            queue_name, properties, redrive_target, tags=tags[1]
-        )
+        queue_tpl = generate_queue_template(queue_name, properties, redrive_target)
     else:
-        queue_tpl = generate_queue_template(queue_name, properties, tags=tags[1])
-    if tags[0]:
-        add_parameters(queue_tpl, tags[0])
-        for tag in tags[0]:
-            parameters.update({tag.title: Ref(tag.title)})
+        queue_tpl = generate_queue_template(queue_name, properties)
     LOG.debug(parameters)
     LOG.debug(session)
     queue_stack = ComposeXStack(
         queue_name,
-        template=queue_tpl,
+        stack_template=queue_tpl,
         Parameters=parameters,
         DependsOn=depends_on,
         **kwargs,
@@ -258,7 +249,7 @@ def add_queue_stack(queue_name, queue, queues, session, tags, **kwargs):
     return queue_stack
 
 
-def generate_sqs_root_template(compose_content, session, **kwargs):
+def generate_sqs_root_template(compose_content, tags=None, session=None, **kwargs):
     """
     Generates a base template for a sqs queues. Iterates over each queue defined
     in x-sqs of the ComposeX file and identify settings and properties for these
@@ -271,25 +262,19 @@ def generate_sqs_root_template(compose_content, session, **kwargs):
     :return: SQS Root/Parent template
     :rtype: troposphere.Template
     """
+    if not session:
+        session = boto3.session.Session()
     validate_kwargs(["BucketName"], kwargs)
     description = "Root SQS Template"
-    if KEYISSET("EnvName", kwargs):
+    if keyisset("EnvName", kwargs):
         description = f"Root SQS Template for {kwargs['EnvName']}"
     root_tpl = build_template(description)
-    params_and_tags = generate_tags_parameters(compose_content)
-    if params_and_tags[0]:
-        add_parameters(root_tpl, params_and_tags[0])
     queues = compose_content[RES_KEY]
     for queue_name in queues:
         LOG.debug(queue_name)
         LOG.debug(session)
         queue_stack = add_queue_stack(
-            queue_name,
-            queues[queue_name],
-            queues.keys(),
-            session,
-            params_and_tags,
-            **kwargs,
+            queue_name, queues[queue_name], queues.keys(), session, **kwargs,
         )
         root_tpl.add_resource(queue_stack)
     return root_tpl
